# The Prefix that will be used on SOLR, Website and Database instances.
$Prefix = "sc910xm1"
# The root folder with the license file, deployment config files and WDP packages.
$SCInstallRoot = "C:\Temp\XM1"
# The DNS name or IP of the Solr computer.
$SolrComputerName = ""
# The DNS name of the Content Management computer.
$CMComputerName = ""
# The DNS name of the Content Delivery computer.
$CDComputerName = ""
# The DNS name of the Identity Server computer.
$IdentityServerComputerName = ""
# The name for the Sitecore Content Management Server.
$SitecoreContentManagementSitename = "$Prefix.cm.local"
# The name for the Sitecore Content Delivery server.
$SitecoreContentDeliverySitename = "$Prefix.cd.local"
# Identity Server site name
$IdentityServerSiteName = "$prefix.identityserver"
# The Path to the license file
$LicenseFile = "$SCInstallRoot\license.xml"
# The URL of the Solr Server
$SolrUrl = "https://solr_host:8983/solr"
# The Folder that Solr has been installed in.
$SolrRoot = "C:\Solr-7.2.1"
# The Name of the Solr Service.
$SolrService = "solr-7.2.1"
# The DNS name or IP of the SQL Instance.
$SqlServer = ""
# A SQL user with sysadmin privileges.
$SqlAdminUser = "sa"
# The password for $SQLAdminUser.
$SqlAdminPassword = "Password12345"
# The path to the Sitecore Content Management Package to Deploy
$SiteCoreContentManagementPackage = (Get-ChildItem "$SCInstallRoot\Sitecore XM 9.1.0 rev. * (OnPrem)_cm.scwdp.zip").FullName
# The path to the Sitecore Content Delivery Package to Deploy
$SitecoreContentDeliveryPackage = (Get-ChildItem "$SCInstallRoot\Sitecore XM 9.1.0 rev. * (OnPrem)_cd.scwdp.zip").FullName
# The path to the Identity Server Package to Deploy.
$IdentityServerPackage = (Get-ChildItem "$SCInstallRoot\Sitecore.IdentityServer 2.0.0 rev. * (OnPrem)_identityserver.scwdp.zip").FullName
# The Identity Server password recovery URL, this should be the URL of the CM Instance
$PasswordRecoveryUrl = "http://$SitecoreContentManagementSitename"
# The URL of the Identity Authority
$SitecoreIdentityAuthority = "https://$IdentityServerSiteName"
#The random string key used for establishing connection with IdentityService
$ClientSecret = "SIF-Default"
#adding allowed CORS Origins, urls of all clients should be added here
$allowedCorsOrigins = "https://$CMComputerName"

#Getting Hosts User credentials:
Write-Host "Hosts user name: "
$HostsUserName = Read-Host
Write-Host "Hosts user password: "
$HostsUserPassword = Read-Host
Clear-Host

# Install XM1 via combined partials file.
$DistributedDeploymentParams = @{
    Path = "$SCInstallRoot\XM1-Distributed.json"
    ComputerUserName = $HostsUserName
    ComputerPassword = $HostsUserPassword
    SitecoreSolrComputerName = $SolrComputerName
    SitecoreSolrUserName = $HostsUserName
    SitecoreSolrPassword = $HostsUserPassword
    SitecoreCMComputerName = $CMComputerName
    SitecoreCDComputerName = $CDComputerName
    IdentityServerComputerName = $IdentityServerComputerName
    LicenseFile = $LicenseFile
    IdentityServerSiteName = $IdentityServerSiteName
    Prefix = $Prefix
    SitecoreContentManagementSitename = $SitecoreContentManagementSitename
    SitecoreContentDeliverySitename = $SitecoreContentDeliverySitename
    SitecoreIdentityAuthority = $SitecoreIdentityAuthority
    SqlAdminUser = $SqlAdminUser
    SqlAdminPassword = $SqlAdminPassword
    SqlServer = $SqlServer
    SolrUrl = $SolrUrl
    SolrRoot = $SolrRoot
    SolrService = $SolrService
    SiteCoreContentManagementPackage = $SiteCoreContentManagementPackage
    SitecoreContentDeliveryPackage = $SitecoreContentDeliveryPackage
    IdentityServerPackage = $IdentityServerPackage
    PasswordRecoveryUrl = $PasswordRecoveryUrl
    ClientSecret = $ClientSecret
    AllowedCorsOrigins = $AllowedCorsOrigins  
}

Push-Location $SCInstallRoot

Install-SitecoreConfiguration @DistributedDeploymentParams -Verbose *>&1 | Tee-Object XM1-Distributed.log

Pop-Location
